@@ -1,8 +1,8 @@
 package ExtUtils::ModuleMaker::Initializers;
 use strict;
-local $^W = 1;
+use warnings;
 use vars qw( $VERSION );
-$VERSION = 0.55;
+$VERSION = 0.56;
 use ExtUtils::ModuleMaker::Licenses::Standard qw(
     Get_Standard_License
     Verify_Standard_License
