@@ -1,11 +1,11 @@
 package ExtUtils::ModuleMaker::Interactive;
 #$Id$
 use strict;
-local $^W = 1;
+use warnings;
 BEGIN {
     use base qw( ExtUtils::ModuleMaker );
     use vars qw ( $VERSION ); 
-    $VERSION = 0.55;
+    $VERSION = 0.56;
 }
 use Carp;
 use Data::Dumper;
@@ -630,7 +630,7 @@ James E Keenan.  CPANID:  JKEENAN.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005, 2016 James E. Keenan.  All rights reserved.
+Copyright (c) 2005, 2017 James E. Keenan.  All rights reserved.
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
